# coding: utf-8

from sqlalchemy import (
    MetaData, String, Table, Column, Integer, Boolean, DateTime)

from migrate.changeset.constraint import ForeignKeyConstraint


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)

    tnx_nodes = Table(
        'tnx_nodes', meta,
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('id', Integer, primary_key=True),
        Column('image_id', Integer, nullable=False),
        Column('dtc_number', Integer),
        Column('unit_number', Integer),
        Column('rack_number', Integer),

        Column('node_id', String(255)),
        Column('node_name', String(255)),
        Column('node_port', String(10)),
        Column('node_mac_address', String(18)),
        Column('is_reserved', Boolean, default=False),
        mysql_charset='utf8'
    )
    tnx_nodes.create()

    tnx_node_images = Table('tnx_node_images', meta, autoload=True)

    fkey = ForeignKeyConstraint(columns=[tnx_nodes.c.image_id],
                                refcolumns=[tnx_node_images.c.id],)
    fkey.create()


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    tnx_nodes = Table('tnx_nodes', meta, autoload=True)
    tnx_nodes.drop()
