# coding: utf-8

from sqlalchemy import MetaData, Table, Column, Integer

from migrate.changeset.constraint import ForeignKeyConstraint


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)

    tnx_nodes = Table('tnx_nodes', meta, autoload=True)
    tnx_power_devices = Table('tnx_power_devices', meta, autoload=True)

    power_device_id = Column('power_device_id', Integer)
    if not hasattr(tnx_nodes.c, 'power_device_id'):
        tnx_nodes.create_column(power_device_id)

    fkey = ForeignKeyConstraint(columns=[tnx_nodes.c.power_device_id],
                                refcolumns=[tnx_power_devices.c.id])
    fkey.create()


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)

    tnx_nodes = Table('tnx_nodes', meta, autoload=True)
    tnx_power_devices = Table('tnx_power_devices', meta, autoload=True)

    if hasattr(tnx_nodes.c, 'power_device_id'):
        tnx_nodes.c.power_device_id.drop()

    fkey = ForeignKeyConstraint(columns=[tnx_nodes.c.power_device_id],
                                refcolumns=[tnx_power_devices.c.id])
    fkey.drop()
