# coding: utf-8

from sqlalchemy import MetaData, String, Table, Column, Integer, DateTime

from migrate.changeset.constraint import ForeignKeyConstraint


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)

    tnx_node_devices = Table(
        'tnx_node_devices', meta,
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('id', Integer, primary_key=True),

        Column('node_id', Integer, nullable=False),
        Column('power_device_id', Integer, nullable=False),
        Column('node_port', String(10)),
        mysql_charset='utf8'
    )
    tnx_node_devices.create()

    # Create FKEYS
    nodes_tbl = Table('tnx_nodes', meta, autoload=True)
    fkey = ForeignKeyConstraint(
        columns=[tnx_node_devices.c.node_id],
        refcolumns=[nodes_tbl.c.id],
    )
    fkey.create()

    power_device_tbl = Table('tnx_power_devices', meta, autoload=True)
    fkey = ForeignKeyConstraint(
        columns=[tnx_node_devices.c.power_device_id],
        refcolumns=[power_device_tbl.c.id],
    )

    fkey.create()


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    tnx_node_devices = Table('tnx_node_devices', meta, autoload=True)
    tnx_node_devices.drop()
