# coding: utf-8

import logging

from sqlalchemy import MetaData, String, Table, Column, Integer

log = logging.getLogger(__name__)


def _archive_nodes_table(meta):
    """Make copy of tnx_nodes table and collect its data"""

    def _create_shadow_table(meta_param, table_name):
        _shadow_table = Table(
            'shadow_' + table_name, meta_param,
            Column('id', Integer, primary_key=True, nullable=False),
            Column('node_pk', Integer),
            Column('node_id', String(255)),
            Column('node_name', String(255)),
            Column('node_port', String(10)),
            Column('power_device_id', Integer),
            mysql_charset='utf8'
        )
        _shadow_table.create()
        return _shadow_table

    shadow_table = _create_shadow_table(meta, 'tnx_nodes')

    # pylint: disable=no-value-for-parameter
    i = shadow_table.insert()

    nodes_tbl = Table('tnx_nodes', meta, autoload=True)
    data = []
    for row in nodes_tbl.select().execute().fetchall():
        (_cr_at, _upd_at, _del_at, _del, id_, _img_id, _dtc_n, _unit_n, _r_n,
         node_id, node_name, node_port, _node_m_addr, _reserv, p_dev_id,
         _title) = row
        i.execute({
            'node_pk': id_,
            'node_id': node_id,
            'node_name': node_name,
            'node_port': node_port,
            'power_device_id': p_dev_id,
        })
        data.append({
            'node_id': node_id,
            'power_device_id': p_dev_id,
            'node_port': node_port,
        })

    return data


def _populate_node_devices_table(meta, data):
    """Fill the tnx_node_devices table"""
    node_devices_tbl = Table('tnx_node_devices', meta, autoload=True)
    # pylint: disable=no-value-for-parameter
    i = node_devices_tbl.insert()
    for row in data:
        power_device_id = row['power_device_id']
        if not power_device_id:
            log.error(u'For {0} power device is not set'.format(row))
            continue

        i.execute({
            'node_id': row['node_id'],
            'power_device_id': power_device_id,
            'node_port': row['node_port'],
        })


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    # backup tnx_nodes table
    data = _archive_nodes_table(meta)
    # fill node_devices table
    _populate_node_devices_table(meta, data)


def downgrade(migrate_engine):
    # TODO restore tnx_nodes table from shadow_tnx_nodes table
    raise NotImplementedError('Downgrade from M2M devices not supported.')
