# coding: utf-8

from migrate.changeset import ForeignKeyConstraint
from sqlalchemy import MetaData, Table

_upgrading_tables = ('tnx_node_devices', 'node_reservs', 'journal',
                     'tnx_power_control_history')


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    tnx_nodes_table = Table('tnx_nodes', meta, autoload=True)

    for table_name in _upgrading_tables:
        table = Table(table_name, meta, autoload=True)
        ForeignKeyConstraint(columns=[table.c.tnx_node_id],
                             refcolumns=[tnx_nodes_table.c.id]).create()

    table = Table('node_reservs', meta, autoload=True)
    ForeignKeyConstraint(columns=[table.c.reserv_tnx_node_id],
                         refcolumns=[tnx_nodes_table.c.id]).create()


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    tnx_nodes_table = Table('tnx_nodes', meta, autoload=True)

    for table_name in _upgrading_tables:
        table = Table(table_name, meta, autoload=True)
        ForeignKeyConstraint(columns=[table.c.tnx_node_id],
                             refcolumns=[tnx_nodes_table.c.id]).drop()

    table = Table('node_reservs', meta, autoload=True)
    ForeignKeyConstraint(columns=[table.c.reserv_tnx_node_id],
                         refcolumns=[tnx_nodes_table.c.id]).drop()
